@@ -2,8 +2,9 @@ package Fey::Meta::HasMany::ViaFK;
 
 use strict;
 use warnings;
+use namespace::autoclean;
 
-our $VERSION = '0.30';
+our $VERSION = '0.31';
 
 use List::AllUtils qw( any );
 
@@ -12,44 +13,39 @@ use MooseX::StrictConstructor;
 
 extends 'Fey::Meta::HasMany';
 
+has 'fk' => (
+    is      => 'ro',
+    isa     => 'Fey::FK',
+    lazy    => 1,
+    builder => '_build_fk',
+);
 
-has 'fk' =>
-    ( is      => 'ro',
-      isa     => 'Fey::FK',
-      lazy    => 1,
-      builder => '_build_fk',
-    );
+has 'order_by' => (
+    is  => 'ro',
+    isa => 'ArrayRef',
+);
 
-has 'order_by' =>
-    ( is  => 'ro',
-      isa => 'ArrayRef',
-    );
-
-
-sub _build_fk
-{
+sub _build_fk {
     my $self = shift;
 
-    $self->_find_one_fk_between_tables( $self->table(), $self->foreign_table(), 1 );
+    $self->_find_one_fk_between_tables( $self->table(),
+        $self->foreign_table(), 1 );
 }
 
-sub _make_iterator_maker
-{
+sub _make_iterator_maker {
     my $self = shift;
 
     my $target_table = $self->foreign_table();
 
-    my $select =
-        $self->associated_class()->schema_class()->SQLFactoryClass()->new_select();
-    $select->select($target_table)
-           ->from($target_table);
+    my $select = $self->associated_class()->schema_class()->SQLFactoryClass()
+        ->new_select();
+    $select->select($target_table)->from($target_table);
 
     my @ph_names;
 
     my $ph = Fey::Placeholder->new();
-    for my $pair ( @{ $self->fk()->column_pairs() } )
-    {
-        my ( $from, $to ) = @{ $pair };
+    for my $pair ( @{ $self->fk()->column_pairs() } ) {
+        my ( $from, $to ) = @{$pair};
 
         $select->where( $to, '=', $ph );
 
@@ -59,18 +55,16 @@ sub _make_iterator_maker
     $select->order_by( @{ $self->order_by() } )
         if $self->order_by();
 
-    my $bind_params_sub =
-        sub { return map { $_[0]->$_() } @ph_names };
+    my $bind_params_sub = sub {
+        return map { $_[0]->$_() } @ph_names;
+    };
 
-    return
-        $self->_make_subref_for_sql( $select,
-                                     $bind_params_sub,
-                                   );
+    return $self->_make_subref_for_sql(
+        $select,
+        $bind_params_sub,
+    );
 }
 
-
-no Moose;
-
 __PACKAGE__->meta()->make_immutable();
 
 1;
